@@ -12,7 +12,7 @@ class DatabaseFeatures(PostgresDatabaseFeatures):
     can_clone_databases = False
 
     # Not supported: https://github.com/cockroachdb/cockroach/issues/40476
-    has_select_for_update_skip_locked = property(operator.attrgetter('is_cockroachdb_22_2'))
+    has_select_for_update_skip_locked = False
 
     # Not supported: https://github.com/cockroachdb/cockroach/issues/31632
     can_defer_constraint_checks = False
@@ -28,8 +28,7 @@ class DatabaseFeatures(PostgresDatabaseFeatures):
     create_test_procedure_without_params_sql = None
     create_test_procedure_with_int_param_sql = None
 
-    # Sequences on AutoField don't begin (or reset) to 1 like other databases
-    # due to use of DEFAULT unique_rowid().
+    # Not supported: https://github.com/cockroachdb/cockroach/issues/20956
     supports_sequence_reset = False
 
     # Forward references in fixtures won't work until cockroachdb can
@@ -58,7 +57,9 @@ class DatabaseFeatures(PostgresDatabaseFeatures):
             'SmallAutoField': 'BigIntegerField',
         }
 
-    supports_order_by_nulls_modifier = property(operator.attrgetter('is_cockroachdb_22_1'))
+    # This can be removed when CockroachDB adds support for NULL FIRST/LAST:
+    # https://github.com/cockroachdb/cockroach/issues/6224
+    supports_order_by_nulls_modifier = False
 
     # CockroachDB doesn't create indexes on foreign keys.
     indexes_foreign_keys = False
@@ -85,14 +86,6 @@ class DatabaseFeatures(PostgresDatabaseFeatures):
     def is_cockroachdb_21_2(self):
         return self.connection.cockroachdb_version >= (21, 2)
 
-    @cached_property
-    def is_cockroachdb_22_1(self):
-        return self.connection.cockroachdb_version >= (22, 1)
-
-    @cached_property
-    def is_cockroachdb_22_2(self):
-        return self.connection.cockroachdb_version >= (22, 2)
-
     @cached_property
     def django_test_expected_failures(self):
         expected_failures = super().django_test_expected_failures
@@ -101,7 +94,6 @@ class DatabaseFeatures(PostgresDatabaseFeatures):
             # https://github.com/cockroachdb/django-cockroachdb/issues/73
             'aggregation.tests.AggregateTestCase.test_add_implementation',
             'aggregation.tests.AggregateTestCase.test_combine_different_types',
-            'expressions.tests.ExpressionsNumericTests.test_complex_expressions',
             # greatest(): expected avg(price) to be of type float, found type
             # decimal: https://github.com/cockroachdb/django-cockroachdb/issues/74
             'aggregation.tests.AggregateTestCase.test_expression_on_aggregation',
@@ -139,6 +131,12 @@ class DatabaseFeatures(PostgresDatabaseFeatures):
             'backends.tests.FkConstraintsTests.test_check_constraints_sql_keywords',
             'backends.tests.FkConstraintsTests.test_disable_constraint_checks_context_manager',
             'backends.tests.FkConstraintsTests.test_disable_constraint_checks_manually',
+            # Passing a naive datetime to cursor.execute() probably can't work
+            # on CockroachDB. The value needs a timezone so psycopg2 will cast
+            # it to timestamptz rather than timestamp to avoid "value type
+            # timestamp doesn't match type timestamptz of column "dt"" but
+            # there aren't any hooks to do that.
+            'timezones.tests.LegacyDatabaseTests.test_cursor_execute_accepts_naive_datetime',
             # SchemaEditor._model_indexes_sql() doesn't output some expected
             # tablespace SQL because CockroachDB automatically indexes foreign
             # keys.
@@ -169,6 +167,9 @@ class DatabaseFeatures(PostgresDatabaseFeatures):
             'many_to_one.tests.ManyToOneTests.test_fk_to_smallautofield',
             'migrations.test_operations.OperationTests.test_smallfield_autofield_foreignfield_growth',
             'migrations.test_operations.OperationTests.test_smallfield_bigautofield_foreignfield_growth',
+            # This backend raises "ValueError: CockroachDB's EXPLAIN doesn't
+            # support any formats." instead of an "unknown format" error.
+            'queries.test_explain.ExplainTests.test_unknown_format',
             # unsupported comparison operator: <jsonb> > <string>:
             # https://github.com/cockroachdb/cockroach/issues/49144
             'model_fields.test_jsonfield.TestQuerying.test_deep_lookup_transform',
@@ -182,43 +183,32 @@ class DatabaseFeatures(PostgresDatabaseFeatures):
             # cannot index a json element:
             # https://github.com/cockroachdb/cockroach/issues/35706
             'schema.tests.SchemaTests.test_func_index_json_key_transform',
-            # unexpected partial unique index in pg_constraint query:
+            # unexpected unique index in pg_constraint query:
             # https://github.com/cockroachdb/cockroach/issues/61098
             'introspection.tests.IntrospectionTests.test_get_constraints_unique_indexes_orders',
+            'schema.tests.SchemaTests.test_func_unique_constraint',
+            'schema.tests.SchemaTests.test_func_unique_constraint_collate',
+            'schema.tests.SchemaTests.test_func_unique_constraint_covering',
+            'schema.tests.SchemaTests.test_unique_constraint_field_and_expression',
+            # ProgrammingError: value type float doesn't match type decimal of
+            # column "n2":
+            # INSERT INTO "db_functions_decimalmodel" ("n1", "n2") VALUES ( -5.75, PI())
+            # (This is fixed in CockroachDB nightly which will be 22.1.)
+            'db_functions.math.test_round.RoundTests.test_decimal_with_precision',
+            # incompatible COALESCE expressions: unsupported binary operator:
+            # <int> * <int> (desired <decimal>):
+            # https://github.com/cockroachdb/cockroach/issues/73587
+            'aggregation.tests.AggregateTestCase.test_aggregation_default_expression',
+            # DataError: incompatible COALESCE expressions: expected pi() to be
+            # of type decimal, found type float
+            # https://github.com/cockroachdb/cockroach/issues/73587#issuecomment-988408190
+            'aggregation.tests.AggregateTestCase.test_aggregation_default_using_decimal_from_database',
         })
-        if not self.connection.features.is_cockroachdb_22_1:
+        if not self.connection.features.is_cockroachdb_21_2:
             expected_failures.update({
-                # Passing a naive datetime to cursor.execute() doesn't work in
-                # older versions of CockroachDB.
-                'timezones.tests.LegacyDatabaseTests.test_cursor_execute_accepts_naive_datetime',
-            })
-        if not self.connection.features.is_cockroachdb_21_1:
-            expected_failures.update({
-                # unimplemented: unable to encode JSON as a table key:
-                # https://github.com/cockroachdb/cockroach/issues/35706
-                'model_fields.test_jsonfield.TestQuerying.test_join_key_transform_annotation_expression',
-                # unknown function: sha224() and sha384():
-                # https://github.com/cockroachdb/django-cockroachdb/issues/81
-                'db_functions.text.test_sha224.SHA224Tests.test_basic',
-                'db_functions.text.test_sha224.SHA224Tests.test_transform',
-                'db_functions.text.test_sha384.SHA384Tests.test_basic',
-                'db_functions.text.test_sha384.SHA384Tests.test_transform',
-                # timezones after 2038 use incorrect DST settings:
-                # https://github.com/cockroachdb/django-cockroachdb/issues/124
-                'expressions.tests.FTimeDeltaTests.test_datetime_subtraction_microseconds',
-                # db_collation appears even if none is specified:
-                # https://github.com/cockroachdb/cockroach/issues/54989
-                'inspectdb.tests.InspectDBTestCase.test_field_types',
-                # Unsupported type conversion: https://github.com/cockroachdb/cockroach/issues/9851
-                'migrations.test_operations.OperationTests.test_alter_fk_non_fk',
-                'schema.tests.SchemaTests.test_alter_field_db_collation',
-                'schema.tests.SchemaTests.test_alter_field_type_and_db_collation',
-                'schema.tests.SchemaTests.test_alter_text_field_to_date_field',
-                'schema.tests.SchemaTests.test_alter_text_field_to_datetime_field',
-                'schema.tests.SchemaTests.test_alter_text_field_to_time_field',
-                'schema.tests.SchemaTests.test_alter_textual_field_keep_null_status',
-                'schema.tests.SchemaTests.test_m2m_rename_field_in_target_model',
-                'schema.tests.SchemaTests.test_rename',
+                # interval division with float rounds differently from Python.
+                # https://github.com/cockroachdb/cockroach/issues/66118
+                'expressions.tests.FTimeDeltaTests.test_durationfield_multiply_divide',
             })
         return expected_failures
 
@@ -233,6 +223,10 @@ class DatabaseFeatures(PostgresDatabaseFeatures):
                 'schema.tests.SchemaTests.test_alter_field_db_collation',
                 'schema.tests.SchemaTests.test_alter_field_type_and_db_collation',
             },
+            # https://github.com/cockroachdb/django-cockroachdb/issues/20
+            'Unsupported query: UPDATE float column with integer column.': {
+                'expressions.tests.ExpressionsNumericTests',
+            },
             # https://github.com/cockroachdb/django-cockroachdb/issues/153#issuecomment-664697963
             'CockroachDB has more restrictive blocking than other databases.': {
                 'select_for_update.tests.SelectForUpdateTests.test_block',
@@ -259,11 +253,4 @@ class DatabaseFeatures(PostgresDatabaseFeatures):
                 'get_or_create.tests.UpdateOrCreateTransactionTests.test_updates_in_transaction',
             },
         })
-        if not self.connection.features.is_cockroachdb_22_1:
-            skips.update({
-                # https://github.com/cockroachdb/django-cockroachdb/issues/20
-                'Unsupported query: UPDATE float column with integer column.': {
-                    'expressions.tests.ExpressionsNumericTests',
-                },
-            })
         return skips
