@@ -1,12 +1,11 @@
 import time
-from datetime import timedelta
 
+from django.db.backends.base.base import timezone_constructor
 from django.db.backends.postgresql.operations import (
     DatabaseOperations as PostgresDatabaseOperations,
 )
 from django.db.utils import OperationalError
 from psycopg2 import errorcodes
-from pytz import timezone
 
 
 class DatabaseOperations(PostgresDatabaseOperations):
@@ -21,7 +20,6 @@ class DatabaseOperations(PostgresDatabaseOperations):
         'AutoField': (-9223372036854775808, 9223372036854775807),
         'BigAutoField': (-9223372036854775808, 9223372036854775807),
     }
-    explain_options = frozenset(['DISTSQL', 'OPT', 'TYPES', 'VEC', 'VERBOSE'])
 
     def deferrable_sql(self):
         # Deferrable constraints aren't supported:
@@ -35,15 +33,8 @@ class DatabaseOperations(PostgresDatabaseOperations):
         """
         # getattr() guards against F() objects which don't have tzinfo.
         if value and getattr(value, 'tzinfo', '') is None and self.connection.timezone_name is not None:
-            connection_timezone = timezone(self.connection.timezone_name)
-            try:
-                value = connection_timezone.localize(value)
-            except OverflowError:
-                # Localizing datetime.datetime.max (used to cache a value
-                # forever, for example) may overflow. Subtract a day to prevent
-                # that.
-                value -= timedelta(days=1)
-                value = connection_timezone.localize(value)
+            connection_timezone = timezone_constructor(self.connection.timezone_name)
+            value = value.replace(tzinfo=connection_timezone)
         return value
 
     def sequence_reset_by_name_sql(self, style, sequences):
@@ -54,18 +45,10 @@ class DatabaseOperations(PostgresDatabaseOperations):
         return []
 
     def explain_query_prefix(self, format=None, **options):
-        extra = []
-        # Normalize options.
-        if options:
-            options = {
-                name.upper(): value
-                for name, value in options.items()
-            }
-            for valid_option in self.explain_options:
-                value = options.pop(valid_option, None)
-                if value:
-                    extra.append(valid_option)
-        prefix = super().explain_query_prefix(format, **options)
+        if format:
+            raise ValueError("CockroachDB's EXPLAIN doesn't support any formats.")
+        prefix = self.explain_prefix
+        extra = [name for name, value in options.items() if value]
         if extra:
             prefix += ' (%s)' % ', '.join(extra)
         return prefix
