@@ -1,5 +1,3 @@
-import operator
-
 from django.contrib.gis.db.backends.postgis.features import (
     DatabaseFeatures as PostGISFeatures,
 )
@@ -9,8 +7,6 @@ from django_cockroachdb.features import DatabaseFeatures as CockroachFeatures
 
 
 class DatabaseFeatures(CockroachFeatures, PostGISFeatures):
-    supports_3d_storage = property(operator.attrgetter('is_cockroachdb_21_1'))
-    supports_3d_functions = property(operator.attrgetter('is_cockroachdb_21_1'))
     supports_raster = False
     # Not supported: https://github.com/cockroachdb/cockroach/issues/57092
     supports_left_right_lookups = False
@@ -38,9 +34,6 @@ class DatabaseFeatures(CockroachFeatures, PostGISFeatures):
             'gis_tests.geoapp.test_functions.GISFunctionsTests.test_union',
             'gis_tests.geoapp.tests.GeoLookupTest.test_gis_lookups_with_complex_expressions',
             'gis_tests.geoapp.tests.GeoLookupTest.test_relate_lookup',
-            # Time zone issue with dates before 1883:
-            # https://github.com/cockroachdb/cockroach/issues/54294
-            'gis_tests.geoapp.test_regress.GeoRegressionTests.test_unicode_date',
             # NotSupportedError: this box2d comparison operator is experimental
             'gis_tests.geoapp.tests.GeoLookupTest.test_contains_contained_lookups',
             # unknown signature: st_dwithin(geography, geometry, decimal) (desired <bool>)
@@ -76,6 +69,12 @@ class DatabaseFeatures(CockroachFeatures, PostGISFeatures):
             # data is currently not supported for columns that are part of an
             # index: https://github.com/cockroachdb/cockroach/issues/47636
             'gis_tests.gis_migrations.test_operations.OperationTests.test_alter_geom_field_dim',
+            # This test assumes the GEOS version used by the database and
+            # Django are the same which isn't the case on CI.
+            'gis_tests.geos_tests.test_geos.GEOSTest.test_emptyCollections',
+            # 3D opclass not present on CockroachDB:
+            # https://github.com/cockroachdb/cockroach/issues/47420#issuecomment-969578772
+            'gis_tests.gis_migrations.test_operations.OperationTests.test_add_3d_field_opclass',
         })
         if not self.connection.features.is_cockroachdb_21_2:
             expected_failures.update({
